# Generated by Django 5.2.7 on 2025-10-17 15:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_seotoolkit', '0003_alter_seoauditissue_issue_severity'),
    ]

    operations = [
        migrations.AlterField(
            model_name='seoauditrun',
            name='status',
            field=models.CharField(choices=[('scheduled', 'Scheduled'), ('running', 'Running'), ('completed', 'Completed'), ('failed', 'Failed')], max_length=255),
        ),
    ]
