# Generated by Django 5.2.7 on 2025-10-22 09:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_seotoolkit', '0005_seoauditissue_requires_dev_fix'),
    ]

    operations = [
        migrations.AlterField(
            model_name='seoauditissue',
            name='issue_type',
            field=models.CharField(choices=[('title_missing', 'Title Missing'), ('title_too_short', 'Title Too Short'), ('title_too_long', 'Title Too Long'), ('meta_description_missing', 'Meta Description Missing'), ('meta_description_too_short', 'Meta Description Too Short'), ('meta_description_too_long', 'Meta Description Too Long'), ('meta_description_duplicate', 'Meta Description Duplicate'), ('meta_description_no_cta', 'Meta Description No CTA'), ('content_empty', 'Content Empty'), ('content_thin', 'Content Thin'), ('content_no_paragraphs', 'Content No Paragraphs'), ('header_no_h1', 'Header No H1'), ('header_multiple_h1', 'Header Multiple H1'), ('header_no_subheadings', 'Header No Subheadings'), ('header_broken_hierarchy', 'Header Broken Hierarchy'), ('image_no_alt', 'Image No Alt Text'), ('image_alt_generic', 'Image Alt Generic'), ('image_alt_too_long', 'Image Alt Too Long'), ('schema_missing', 'Schema Missing'), ('schema_no_organization', 'Schema No Organization/Person'), ('schema_no_article', 'Schema No Article/BlogPosting'), ('schema_invalid', 'Schema Invalid'), ('mobile_no_viewport', 'Mobile No Viewport'), ('mobile_fixed_width', 'Mobile Fixed Width'), ('mobile_text_small', 'Mobile Text Small'), ('internal_links_none', 'Internal Links None'), ('internal_links_few', 'Internal Links Few'), ('internal_links_all_external', 'Internal Links All External'), ('content_not_updated', 'Content Not Updated'), ('content_no_publish_date', 'Content No Publish Date'), ('content_no_modified_date', 'Content No Modified Date'), ('performance_score_low', 'Performance Score Low'), ('performance_score_critical', 'Performance Score Critical'), ('accessibility_score_low', 'Accessibility Score Low'), ('accessibility_score_critical', 'Accessibility Score Critical'), ('best_practices_score_low', 'Best Practices Score Low'), ('best_practices_score_critical', 'Best Practices Score Critical'), ('seo_score_low', 'SEO Score Low'), ('seo_score_critical', 'SEO Score Critical'), ('lighthouse_audit_failed', 'Lighthouse Audit Failed')], max_length=255),
        ),
    ]
