# Generated by Django 5.2.7 on 2025-10-24 13:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_seotoolkit', '0007_update_pagespeed_issue_type_names'),
    ]

    operations = [
        migrations.CreateModel(
            name='PluginEmailVerification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, unique=True)),
                ('is_verified', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'verbose_name': 'Plugin Email Verification',
                'verbose_name_plural': 'Plugin Email Verifications',
            },
        ),
    ]
