# Generated by Django 5.2.7 on 2025-10-15 15:36

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wagtail_seotoolkit", "0001_initial"),
        ("wagtailcore", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name='seoauditissue',
            name='page',
            field=models.ForeignKey(blank=True, help_text='The page this issue relates to', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='seo_issues', to='wagtailcore.page'),
        ),
    ]
